Index: wp-admin/includes/post.php
===================================================================
--- wp-admin/includes/post.php	(revision 14044)
+++ wp-admin/includes/post.php	(working copy)
@@ -1043,7 +1043,7 @@
 
 	// Handle page hierarchy
 	if ( $ptype->hierarchical ) {
-		$uri = get_page_uri($post->ID);
+		$uri = get_page_uri($post);
 		$uri = untrailingslashit($uri);
 		$uri = strrev( stristr( strrev( $uri ), '/' ) );
 		$uri = untrailingslashit($uri);
Index: wp-includes/post.php
===================================================================
--- wp-includes/post.php	(revision 14044)
+++ wp-includes/post.php	(working copy)
@@ -2904,11 +2904,12 @@
  *
  * @since 1.5.0
  *
  * @param int $page_id Page ID.
  * @return string Page URI.
  */
-function get_page_uri($page_id) {
-	$page = get_page($page_id);
+function get_page_uri($page) {
+	if ( ! is_object($page) )
+		$page = get_page($page);
 	$uri = $page->post_name;
 
 	// A page cannot be it's own parent.
@@ -2904,11 +2904,12 @@
  * @since 1.5.0
  *
- * @param int $page_id Page ID.
+ * @param mixed $page Page object or page ID.
  * @return string Page URI.
  */
